var async    = require('async');
var canvass;
module.exports = {
    '@tags': ['cf_copyPasteMouse'],
    before: function (client) {
        client
            .url(client.launchUrl)
            .waitForElementVisible('body', 1000);
    },

    after: function (client) {

        client.end();
    },
    /**
     *  Test: 1-001
     *  Expects:
     *      - Node should be added in the canvass
     */
    "1-001": function (client) {
        async.series([
            //load HARK Designer
            function (callback) {
                canvass = client.page.canvass();
                canvass.navigate();

                //check if body is now visible
                canvass.expect.element('body').to.be.present;

                //should have Main sheet
                canvass.expect.element('@mainSheet').to.be.visible;
                callback();
            },
            //add one node to canvass
            function (callback) {
                canvass.addNodeByName('NNETExec', function () {
                    canvass.expect.element('@nodeDOM').to.be.visible;
                    callback();
                });
            }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-002
     *  Expects:
     *      - Context menu should be displayed
     */
    "1-002": function (client) {
        async.series([
                //select node
                function (callback) {
                    canvass.selectNode('@nodeDOM', function(){
                        callback();
                    });
                },
                //node should be selected
                function (callback) {
                    canvass.expect.element('@nodeDOM').to.have.attribute('class').contains('nodeSelected');
                    callback();
                },
                //right click to the added node of the canvass
                function (callback) {
                    client
                        .moveToElement('#node_NNetExec_1', 10, 10)
                        .mouseButtonClick('right', function(){
                            callback();
                        });
                },
                //check if context menu is displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 2000, function(){
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-003
     *  Expects:
     *      - Context menu should be closed
     */
    "1-003": function (client) {
        async.series([
                //check if there's copy option
                function (callback) {
                    canvass.waitForElementPresent('@copyOption', 2000, function () {
                        canvass.expect.element('@copyOption').to.be.visible;
                        callback();
                    });
                },
                //select copy from the context menu
                function (callback) {
                    canvass.click('@copyOption', function(){
                        callback();
                    });
                },
                //pause
                function (callback) {
                    canvass.api.pause(1000, function () {
                        callback();
                    });
                },
                //context menu should be closed
                function (callback) {
                    canvass.waitForElementNotPresent('@mainContextMenu', 1000, function () {
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-004
     *  Expects:
     *      - Copied node should be pasted in the sheet selected
     */
    "1-004": function (client) {
        async.series([
                //Paste the copied node in the selected sheet
                function (callback) {
                    canvass.paste(client, 'html > body > div#container > div#sheets > div:nth-of-type(1)', 1, function(){
                        callback();
                    });
                },
                //check if a second node is added
                function (callback) {
                    canvass.expect.element('@nodeDOM2').to.be.visible;
                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-005
     *  Expects:
     *      - Copied Node should be pasted in the other sheet
     */
    "1-005": function (client) {
        async.series([
                //Create new tab
                function (callback) {
                    canvass.addSheet('test1', function(){
                        callback();
                    });
                },
                //check if new tab is added
                function (callback) {
                    canvass.expect.element('@sheet1').to.be.visible;
                    callback();
                },
                //paste copied node
                function (callback) {
                    canvass.paste(client, 'html > body > div#container > div#sheets > div:nth-of-type(2)', 1, function(){
                        callback();
                    });
                },
                //check if a third node is added
                function (callback) {
                    canvass.expect.element('@nodeDOM3').to.be.visible;
                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-006
     *  Expects:
     *      - Nodes should be selected
     *      - Nodes should have shadow as indicator that it should be selected.
     */
    "1-006": function (client) {
        async.series([
                //add another node
                function (callback) {
                    canvass.addNodeByName('NNETExec', function(){
                        callback();
                    });
                },
                //add another node
                function(callback) {
                    //check if node is added
                    canvass.expect.element('@nodeDOM4').to.be.visible;

                    //add another node
                    canvass.addNodeByName('NNETExec', function(){
                        callback();
                    });
                },
                //add another node
                function(callback) {
                    //check if node is added
                    canvass.expect.element('@nodeDOM5').to.be.visible;
                    callback();
                },
                //select all nodes
                function (callback) {
                    canvass.selectNodes(client, 'html > body > div#container > div#sheets > div:nth-of-type(2)', function(){
                        callback();
                    });
                },
                //check if all nodes are selected
                function (callback) {
                    //check if node 3 is selected
                    canvass.expect.element('@nodeDOM3').to.have.attribute('class').contains('nodeSelected');
                    //check if node 4 is selected
                    canvass.expect.element('@nodeDOM4').to.have.attribute('class').contains('nodeSelected');
                    //check if node 5 is selected
                    canvass.expect.element('@nodeDOM5').to.have.attribute('class').contains('nodeSelected');

                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-007
     *  Expects:
     *      - Context menu should be displayed
     */
    "1-007": function (client) {
        async.series([
                //right click to the added node of the canvass
                function (callback) {
                    client
                        .moveToElement('#node_NNetExec_5', 3, 3)
                        .mouseButtonClick('right', function(){
                            callback();
                        });
                },
                //check if context menu is displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 2000, function(){
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-008
     *  Expects:
     *      - Context menu should be closed
     */
    "1-008": function (client) {
        async.series([
                //check if there's copy option
                function (callback) {
                    canvass.waitForElementPresent('@copyOption', 2000, function () {
                        canvass.expect.element('@copyOption').to.be.visible;
                        callback();
                    });
                },
                //select copy from the context menu
                function (callback) {
                    canvass.click('@copyOption', function(){
                        callback();
                    });
                },
                //pause
                function (callback) {
                    canvass.api.pause(1000, function () {
                        callback();
                    });
                },
                //context menu should be closed
                function (callback) {
                    canvass.waitForElementNotPresent('@mainContextMenu', 1000, function () {
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-009
     *  Expects:
     *      - Copied nodes should be pasted in the sheet selected
     *      - Links should be drawn if the nodes selected have a link.
     */
    "1-009": function (client) {
        async.series([
                //paste copied nodes
                function (callback) {
                    canvass.paste(client, 'html > body > div#container > div#sheets > div:nth-of-type(2)', 1, function(){
                        callback();
                    });
                },
                //check if a nodes are added
                function (callback) {
                    //check if a sixth node is added
                    canvass.expect.element('@nodeDOM6').to.be.visible;
                    //check if a seventh node is added
                    canvass.expect.element('@nodeDOM7').to.be.visible;
                    //check if a eight node is added
                    canvass.expect.element('@nodeDOM8').to.be.visible;
                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 1-010
     *  Expects:
     *      - Copied Nodes should be pasted in the other sheet.
     *      - Links should be drawn if the nodes selected have a link.
     */
    "1-010": function (client) {
        async.series([
                //Create new tab
                function (callback) {
                    canvass.addSheet('test2', function(){
                        callback();
                    });
                },
                //check if new tab is added
                function (callback) {
                    canvass.expect.element('@sheet2').to.be.visible;
                    callback();
                },
                //paste copied node
                function (callback) {
                    canvass.paste(client, 'html > body > div#container > div#sheets > div:nth-of-type(3)', 1, function(){
                        callback();
                    });
                },
                //check if nodes are added
                function (callback) {
                    canvass.expect.element('@nodeDOM9').to.be.visible;
                    canvass.expect.element('@nodeDOM10').to.be.visible;
                    canvass.expect.element('@nodeDOM11').to.be.visible;
                    callback();
                }
            ],
            function () {
                //Finished
            });
    }
};