var async    = require('async');
var canvass;
module.exports = {
    '@tags': ['cf_condition'],
    before: function (client) {
        client
            .url(client.launchUrl)
            .waitForElementVisible('body', 1000);
    },

    after: function (client) {

        client.end();
    },
    /**
     *  Test: 8-001
     *  Expects:
     *      - Hark Designer will be loaded in the browser.
     *      - Nodes and links should be drawn in the sheet.
     */
    "8-001": function (client) {
        async.series([
                //load HARK Designer
                function(callback){
                    canvass = client.page.canvass();
                    canvass.navigate();

                    //check if body is now visible
                    canvass.expect.element('body').to.be.present;

                    //should have Main sheet
                    canvass.expect.element('@mainSheet').to.be.visible;

                    callback();
                },
                //setup fixture
                function (callback) {
                    canvass.loadFixture(client, function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-002
     *  Expects:
     *      - Context menu will appear
     */
    "8-002": function (client) {
        async.series([
                //select LOOP sheet
                function(callback) {
                    canvass.selectSheet('@sheet1Tab', function () {
                        canvass.expect.element('@nodeAudioStreamFromWave1').to.be.visible;
                        callback();
                    });
                },
                //mouse over NOT_EOF of AudioStreamFromWave node
                function (callback) {
                    client.moveToElement('#node_AudioStreamFromWave_1_delim_NOT_EOF', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    });
                },
                //context menu should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu2', 1000, function () {
                        canvass.expect.element('@mainContextMenu2').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-003
     *  Expects:
     *      - Red labeled CONDITION will appear in the canvass besides the NOT_EOF terminal.
     */
    "8-003": function (client) {
        async.series([
                //click set as condition option
                function (callback) {
                    canvass.click('@setAsConditionOption', function(){
                        canvass.api.pause(1000, function(){
                            callback();
                        });
                    });
                },
                //check if CONDITION is present
                function (callback){
                    canvass.expect.element('@nodeAudioStreamFromWave1CONDITION').to.be.present;
                    canvass.expect.element('@nodeAudioStreamFromWave1CONDITION').text.to.equal('CONDITION');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-004
     *  Expects:
     *      - Save sheet dialog should be closed
     */
    "8-004": function (client) {
        async.series([
                //save network as sample_network.n
                function (callback) {
                    canvass.saveNetwork(client, 'sample_network.n', function () {
                        callback();
                    });
                },
                //Save sheet dialog should be closed
                function(callback) {
                    canvass.expect.element('@saveSheetDialog').to.not.be.visible;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-005
     *  Expects:
     *      - The saved network "sample_network.n" will be loaded in the Hark Designer.
     *      - AudioStreamFromWave with red labeled CONDITION should be drawn in the sheet.
     */
    "8-005": function (client) {
        async.series([
                //load sample_network.n
                function (callback) {
                    canvass.loadNetwork(client, 'sample_network.n', function () {
                        callback();
                    })
                },
                //check if CONDITION is present
                function(callback) {
                    canvass.expect.element('@nodeAudioStreamFromWave1CONDITION').to.be.present;
                    canvass.expect.element('@nodeAudioStreamFromWave1CONDITION').text.to.equal('CONDITION');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-006
     *  Expects:
     *      - Context menu will appear
     */
    "8-006": function (client) {
        async.series([
                //select LOOP sheet
                function(callback) {
                    canvass.selectSheet('@sheet1Tab', function () {
                        callback();
                    });
                },
                //mouse over 01_SPEC of NormalizeMUSIC node
                function (callback) {
                    client.moveToElement('#node_NormalizeMUSIC_1_delim_01_SPEC', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    });
                },
                //context menu should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu2', 1000, function () {
                        canvass.expect.element('@mainContextMenu2').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-007
     *  Expects:
     *      - Error should be displayed in the console that says "Error: Role name already exist in the sheet"
     *      -The requirements of the condition are:
     *          (1) only the output terminals in iterator sheets can be a condition
     *          (2) only one output terminal can be the condition in one sheet
     */
    "8-007": function (client) {
        async.series([
                //click set as condition option
                function (callback) {
                    canvass.click('@setAsConditionOption', function(){
                        canvass.api.pause(1000, function(){
                            callback();
                        });
                    });
                },
                //check if CONDITION is not added
                function (callback){
                    canvass.expect.element('@nodeNormalizeMUSIC1CONDITION').text.to.not.equal('CONDITION');
                    canvass.expect.element('@consoleText').text.to.equal('Error: Role name already exist in the sheet');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-008
     *  Expects:
     *      - Context menu will appear
     *      - Red-labeled CONDITION will be removed from the sheet.
     */
    "8-008": function (client) {
        async.series([
                //delete CONDITION of nodeAudioStreamFromWave
                function (callback) {
                    canvass.deleteCondition(client, '#node_AudioStreamFromWave_1_delim_NOT_EOF', function () {
                        callback();
                    });
                },
                //check if CONDITION is deleted
                function (callback){
                    canvass.expect.element('@nodeAudioStreamFromWave1CONDITION').text.to.not.equal('CONDITION');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-009
     *  Expects:
     *      - Context menu will appear.
     *      - Red-labeled CONDITION will be drawn besides the 01_SPEC output of NormalizeMUSIC.
     */
    "8-009": function (client) {
        async.series([
                //set 01_SPEC of nodenodeNormalizeMUSIC as CONDITION
                function (callback) {
                    canvass.setAsCondition(client, '#node_NormalizeMUSIC_1_delim_01_SPEC', function () {
                        callback();
                    });
                },
                //check if CONDITION is added
                function (callback){
                    canvass.expect.element('@nodeNormalizeMUSIC1CONDITION').text.to.equal('CONDITION');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-010
     *  Expects:
     *      - Save sheet dialog should be closed
     */
    "8-010": function (client) {
        async.series([
                //save network as sample_network.n
                function (callback) {
                    canvass.saveNetwork(client, 'sample_network.n', function () {
                        callback();
                    });
                },
                //Save sheet dialog should be closed
                function(callback) {
                    canvass.expect.element('@saveSheetDialog').to.not.be.visible;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 8-011
     *  Expects:
     *      - The saved network "sample_network.n" will be loaded in the Hark Designer.
     *      - NormalizeMUSIC with red labeled CONDITION should be drawn in the sheet.
     */
    "8-011": function (client) {
        async.series([
                //load sample_network.n
                function (callback) {
                    canvass.loadNetwork(client, 'sample_network.n', function () {
                        callback();
                    })
                },
                //check if CONDITION is present
                function(callback) {
                    canvass.expect.element('@nodeNormalizeMUSIC1CONDITION').to.be.present;
                    canvass.expect.element('@nodeNormalizeMUSIC1CONDITION').text.to.equal('CONDITION');
                    callback();
                }
            ],
            function(){
                //finished
            });
    }
};
