var async = require('async');
var moment = require('moment');
var fs = require('fs-extra');
var del = require('del');
var path = require('path');

var defaultDir = '/usr/src/app/userdata/networks';
var dLoadDir = '/home/seluser/Downloads';

function screenshot (client) {
    var fileName = moment().format('YYYYMMDDHHmmss');
    var screenShotPath = './automated-tests/screenshots/';
    var fileFormat = '.png';
    var filePath = screenShotPath+fileName+fileFormat;

    client.saveScreenshot(filePath);
}

module.exports = {
    '@tags': ['fm_fileSave'],

    before: function (client) {
        client
            .url('http://localhost:3000')
            .waitForElementVisible('#topmenu', 1000);
    },

    after: function (client) {
        // Clean up
        del.sync(defaultDir + '/*');
        del.sync(dLoadDir + '/*', {force: true});
        del.sync('/home/seluser/SampleNetwork*', {force: true});

        client.end();
    },

    /**
     *  Test: 4-001
     *  Expects:
     *      - Save network dialog with appear with input box for network name.
     */
    "4-001": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) {
                // Hover to category
                fileManagement.moveToElement('@CATEio', 10,10, function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Add node
                fileManagement.click('@NODEinputStream', function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Hover to category
                fileManagement.moveToElement('@CATEharkAudioIO', 10,10, function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Add node
                fileManagement.click('@NODEsaveWavePCM', function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Link nodes
                fileManagement.linkNodes(fileManagement.elements.OUTinputStream.selector,
                    fileManagement.elements.INsaveWavePCM.selector , 0, 3);

                client.pause(1000, function () {
                    callback();
                });
            },
            function (callback) {
                fileManagement.clickSave();

                fileManagement.expect.element('@saveDialog').to.be.visible;

                callback();
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-002
     *  Expects:
     *      - Save network dialog with appear with input box for network name.
     */
    "4-002": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) { // Test: 4-002
                // Set file name
                fileManagement.setValue('@saveInput', 'SampleNetwork');

                // Click ok
                fileManagement.click('@saveOK');

                // Assert save dialog to close
                fileManagement.expect.element('@saveDialog').to.be.not.visible.after(1000);

                // Assert if correct file is opened
                fileManagement.expect.element('@fileName').text.to.contain('SampleNetwork').after(1000);

                callback();
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-003
     *  Expects:
     *      - In the file list, SampleNetwork should be displayed.
     */
    "4-003": function (client) {
        var fileManagement = client.page.fileManagement();

        // Open file manager
        fileManagement.open();

        // Clear value for filter
        fileManagement.clearValue('@filter');

        // Select filter
        fileManagement.moveToElement('@filter', 10, 10);

        // Enter 'SampleNetwork'
        client.keys('SampleNetwork', function () {
            client.pause(1000, function () {
                // Assert file if present in file list
                fileManagement.expect.element('@fileList').text.to.contain('SampleNetwork').after(1000);
            });
        });
    },

    /**
     *  Test: 4-004
     *  Expects:
     *      - File list should display files under documents folder.
     */
    "4-004": function (client) {
        var fileManagement = client.page.fileManagement();

        // Select file path
        fileManagement.moveToElement('@dataPath', 10, 10);

        // Clear file path value
        fileManagement.clearValue('@dataPath');

        // Set file path value
        fileManagement.setValue('@dataPath', '/home/seluser');

        // Hit enter key
        client.keys(client.Keys.ENTER, function () {
            client.pause(1000, function () {
                // Assert files if present in file list
                fileManagement.expect.element('@fileList').text.to.not.equals('').after(1000);
            });
        });
    },

    /**
     *  Test: 4-005
     *  Expects:
     *      - File Manager dialog should close.
     */
    "4-005": function (client) {
        var fileManagement = client.page.fileManagement();

        // Close file manager
        fileManagement.close();

        // Assert file manager to close
        fileManagement.expect.element('@fileManagerDialog').to.be.not.visible.after(1000);
    },

    /**
     *  Test: 4-006
     *  Expects:
     *      - Save network dialog will close.
     *      - In console, File Name will display "SampleNetwork".
     */
    "4-006": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) {
                // Click save button
                fileManagement.clickSave();

                fileManagement.expect.element('@saveDialog').to.be.visible;

                callback();
            },
            function (callback) {
                // Clears value
                fileManagement.clearValue('@saveInput');

                // Set file name
                fileManagement.setValue('@saveInput', 'SampleNetwork');

                // Click ok
                fileManagement.click('@saveOK');

                // Assert save dialog to close
                fileManagement.expect.element('@saveDialog').to.be.not.visible.after(1000);

                // Assert if correct file is opened
                fileManagement.expect.element('@fileName').text.to.contain('SampleNetwork').after(1000);

                callback();
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-007
     *  Expects:
     *      - In the file list, SampleNetwork should be displayed.
     */
    "4-007": function (client) {
        var fileManagement = client.page.fileManagement();

        // Open file manager
        fileManagement.open();

        // Clear value for filter
        fileManagement.clearValue('@filter');

        // Select filter
        fileManagement.moveToElement('@filter', 10, 10);

        // Enter 'SampleNetwork'
        client.keys('SampleNetwork', function () {
            client.pause(1000, function () {
                // Assert file if present in file list
                fileManagement.expect.element('@fileList').text.to.contain('SampleNetwork').after(1000);
            });
        });
    },

    /**
     *  Test: 4-008
     *  Expects:
     *      - File Manager dialog should close.
     */
    "4-008": function (client) {
        var fileManagement = client.page.fileManagement();

        // Close file manager
        fileManagement.close();

        // Assert file manager to close
        fileManagement.expect.element('@fileManagerDialog').to.be.not.visible.after(1000);
    },

    /**
     *  Test: 4-009
     *  Expects:
     *      - Default dialog box will appear asking "Are you sure to clear current network?".
     *      - "Ok" and "Cancel" button must be present in the prompt.
     */
    "4-009": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) { // Test: 4-009
                // Click clear button
                fileManagement.clickClear();

                // Assert alert box if present
                client.getAlertText(function (result) {
                    if (result.value === "Are you sure to clear current network?") {
                        callback();
                    }
                    else {
                        client.assert.fail(result.value, 'Are you sure to clear current network?', "Alert should be visible");
                    }
                });
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-010
     *  Expects:
     *      - Default dialog box will be closed.
     *      - Canvass will not be cleared.
     */
    "4-010": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) { // Test: 4-010
                client.pause(1000);

                // Cancels alert box
                client.dismissAlert(function () {
                    callback();
                });
            },
            function (callback) {
                // Assert alert box if present
                client.getAlertText(function (result) {
                    if (result.value === "Are you sure to clear current network?") {
                        client.assert.fail(result.value, "", "Alert should not be visible");
                    }
                    else {
                        callback();
                    }
                });
            },
            function (callback) {
                // Assert canvas to not be cleared
                fileManagement.expect.element('@canvasDiv').text.not.equals('');

                callback();
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-011
     *  Expects:
     *      - Prompt will disappear.
     *      - The canvass will be cleared.
     */
    "4-011": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) { // Test: 4-011
                // Click clear button
                fileManagement.clickClear();

                client.pause(1000);

                // Accept alert box
                client.acceptAlert(function () {
                    callback();
                });
            },
            function (callback) {
                client.pause(1000, function () {
                    // Assert alert box if present
                    client.getAlertText(function (result) {
                        if (result.value === "Are you sure to clear current network?") {
                            client.assert.fail(result.value, "", "Alert should not be visible");
                        }
                        else {
                            callback();
                        }
                    });
                });
            },
            function (callback) {
                // Assert canvas to not be cleared
                fileManagement.expect.element('@canvasDiv').text.equals('');

                callback();
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-012
     *  Expects:
     *      - Default dialog box will appear asking "Overwrite network?"
     */
    "4-012": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) {
                // Hover to category
                fileManagement.moveToElement('@CATEio', 10,10, function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Add node
                fileManagement.click('@NODEinputStream', function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Hover to category
                fileManagement.moveToElement('@CATEharkAudioIO', 10,10, function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Add node
                fileManagement.click('@NODEsaveWavePCM', function () {
                    client.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                // Link nodes
                fileManagement.linkNodes(fileManagement.elements.OUTinputStream.selector,
                    fileManagement.elements.INsaveWavePCM.selector , 0, 3);

                client.pause(1000, function () {
                    callback();
                });
            },
            function (callback) {
                // Click save
                fileManagement.clickSave();

                callback();
            },
            function (callback) {
                // Set file name
                fileManagement.setValue('@saveInput', 'SampleNetwork');

                // Click ok
                fileManagement.click('@saveOK');

                client.pause(1000);

                callback();
            },
            function (callback) {
                // Assert alert box if present
                client.getAlertText(function (result) {
                    if (result.value === "Overwrite network?") {
                        callback();
                    }
                    else {
                        client.assert.fail(result.value, "Overwrite network?", "Alert should be visible");
                    }
                });
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-013
     *  Expects:
     *      - Default dialog box will be closed.
     *      - Network will not be overwritten.
     */
    "4-013": function (client) {
        async.series([
            function (callback) { // Test: 4-013
                // Cancels alert box
                client.dismissAlert(function () {
                    client.pause(1000, function () {
                        // Assert alert box if present
                        client.getAlertText(function (result) {
                            if (result.value === "Are you sure to clear current network?") {
                                client.assert.fail(result.value, "", "Alert should not be visible");
                            }
                            else {
                                callback();
                            }
                        });
                    });
                });
            }
        ], function () {
            // nothing
        });
    },

    /**
     *  Test: 4-014
     *  Expects:
     *      - Prompt will disappear.
     *      - Network will be overwritten.
     */
    "4-014": function (client) {
        var fileManagement = client.page.fileManagement();

        async.series([
            function (callback) { // Test: 4-014
                // Click save
                fileManagement.clickSave();

                client.pause(1000);

                // Accept alert box
                client.acceptAlert(function () {
                    callback();
                });
            },
            function (callback) {
                client.pause(1000, function () {
                    // Assert alert box if present
                    client.getAlertText(function (result) {
                        if (result.value === "Are you sure to clear current network?") {
                            client.assert.fail(result.value, "", "Alert should not be visible");
                        }
                        else {
                            callback();
                        }
                    });
                });
            }
        ], function () {
            // nothing
        });
    }
};