var async = require('async');
module.exports = {
    '@tags': ['pd_reset'],

    before: function (client) {
        client
            .url('http://localhost:3000')
            .waitForElementVisible('#topmenu', 1000);
    },

    after: function (client) {
        client.end();
    },

    /**
     * Test: 3-001
     * Expects:
     *  - Preferences dialog will appear with 6 buttons
     */
    '3-001': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@preferenceDialog').to.be.visible;
                callback();
            },
            function (callback) {
                // 3-001
                preferenceTest.expect.element('@packagesBtn').to.be.visible;
                preferenceTest.expect.element('@displayBtn').to.be.visible;
                preferenceTest.expect.element('@versionBtn').to.be.visible;
                preferenceTest.expect.element('@resetBtn').to.be.visible;
                preferenceTest.expect.element('@tutorialBtn').to.be.visible;
                preferenceTest.expect.element('@environmentBtn').to.be.visible;
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-002
     * Expects:
     *  - In the dialog it should display the def files (e.g. libhark.def. libeffect, etc.)
     *  - The display should be in this order:
     *  [bullets] -  name_of_def  - dropdown menu for the preferences.
     *  - All buttons bullets should be enabled(solid circle) and clickable.
     */
    '3-002': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        function checkPackages(package) {
            preferenceTest.expect.element(package).to.be.visible;
        }

        function checkBtnEnabled(element) {
            preferenceTest.expect.element(element).to.have.attribute('class').contains('ui-icon-bullet');
        }

        async.series([
            function (callback) {
                preferenceTest.clickPackagesButton(function () {
                    client.pause(1000, function () {
                        preferenceTest.expect.element('@packagesDialog').to.have.attribute('style').contains('display: block;');
                    });
                    callback();
                });
            },
            function (callback) {
                // 1-002 Check if default packages are visible
                checkPackages('@package_nnet');
                checkPackages('@package_audioBlocks');
                checkPackages('@package_dataflow');
                checkPackages('@package_effects');
                checkPackages('@package_fuzzy');
                checkPackages('@package_hark');
                checkPackages('@package_hmm');
                checkPackages('@package_vq');

                checkBtnEnabled('@packageBtn_nnet');
                checkBtnEnabled('@packageBtn_audioBlocks');
                checkBtnEnabled('@packageBtn_dataflow');
                checkBtnEnabled('@packageBtn_effects');
                checkBtnEnabled('@packageBtn_fuzzy');
                checkBtnEnabled('@packageBtn_hark');
                checkBtnEnabled('@packageBtn_hmm');
                checkBtnEnabled('@packageBtn_vq');


                for(var i = 0; i > 9; i++) {
                    preferenceTest.expect.element('@packagesDialogValue' + i).to.be.enabled;
                }
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-003
     * Expects:
     *  - hark.def. will be disabled, bullet should change from solid circle to hollow circle icon
     *    and dropdown should be disabled.
     *  - In the "Package" button, info icon (color blue) will be displayed.
     *  - Info icon indicates that not all packages are loaded.
     */
    '3-003': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.clickHarkDefBullet(function () {
                    callback();
                });
            },
            function (callback) {
                // 3-003
                preferenceTest.expect.element('@harkDefSelect').to.be.not.enabled;
                preferenceTest.expect.element('@packageBtn_hark').to.have.attribute('class').contains('ui-icon-radio-off');
                preferenceTest.expect.element('@infoIcon').to.have.attribute('class').contains('ui-icon-info');
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-004
     * Expects:
     *  - hark.def. will be disabled, bullet should change from solid circle to hollow circle icon
     *    and dropdown should be disabled.
     *  - In the "Package" button, info icon (color blue) will be displayed.
     *  - Info icon indicates that not all packages are loaded.
     */
    '3-004': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.setValue('@packagesDialogValue2', 'Sea');
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@packagesDialogValue4', 'Fire');
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@packagesDialogValue3', 'Dark');
                callback();
            },
            function (callback) {
                //3-004
                preferenceTest.expect.element('@packagesDialogValue2').to.have.value.that.equals('Sea');
                preferenceTest.expect.element('@packagesDialogValue3').to.have.value.that.equals('Dark');
                preferenceTest.expect.element('@packagesDialogValue4').to.have.value.that.equals('Fire');
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-005
     * Expects:
     *  - Line: Lines
     *  - Language: Japanese
     *  - Show Tooltips: No
     */
    '3-005': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.setValue('@displayDialogValue1', 'Lines');
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@displayDialogValue2', 'Japanese');
                callback();
            },
            function (callback) {
                preferenceTest.setValue('@displayDialogValue3', 'No');
                callback();
            },
            function (callback) {
                // 3-005
                preferenceTest.expect.element('@displayDialogValue1').to.have.value.that.equals('Lines');
                preferenceTest.expect.element('@displayDialogValue2').to.have.value.that.equals('ja');
                preferenceTest.expect.element('@displayDialogValue3').to.have.value.that.equals('No');
                callback();
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-006
     * Expects:
     *  - Dialog box will appear saying "Do you really want to reset all preferences?"
     *  - After clicking OK, Hark Designer will be reloaded.
     */
    '3-006': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.clickResetButton();
                callback();
            },
            function (callback) {
                client.pause(1000, function () {
                    callback();
                });
            },
            function (callback) {
                client.acceptAlert(function () {
                    callback();
                });
            },
            function (callback) {
                client.pause(5000, function () {
                    preferenceTest.expect.element('body').to.be.visible;
                    callback();
                });
            }
        ], function (err, stdout) {

        });
    },

    /**
     * Test: 3-007
     * Expects:
     *  - All libraries should be enabled.
     *  - All theme should be in Classic.
     *  - Line, Language and Show Tooltips will reset to its default value.
     *  Line: Bezier
     *  Language: English
     *  Show Tooltips: Yes
     */
    '3-007': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickPackagesButton(function () {
                    callback();
                });
            },
            function (callback) {
                // 3-007
                for(var i = 1; i < 9; i++) {
                    preferenceTest.expect.element('@packagesDialogValue' + i).to.be.enabled;
                    preferenceTest.expect.element('@packagesDialogValue' + i).to.have.value.that.equals('Classic');
                }
                callback();
            },
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@displayDialogValue1').to.have.value.that.equals('Bezier');
                preferenceTest.expect.element('@displayDialogValue2').to.have.value.that.equals('en');
                preferenceTest.expect.element('@displayDialogValue3').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue4').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue5').to.have.value.that.equals('fold');
                callback();
            }
        ], function (err, stdout) {

        });

        client.end();
    }
}